@@ -5,7 +5,7 @@
 #extra=" --enable-amr_nb --enable-amr_nb-fixed --enable-amr_wb --enable-amr_if2"
 
 #apt-get install liba52-dev libfaad-dev libgsm1-dev
-#extra=" --enable-liba52 --enable-libfaad --enable-libgsm"
+#extra=" --enable-libfaad --enable-libgsm"
 
 common="--enable-gpl --enable-swscale --enable-postproc --disable-encoders --enable-libvorbis"
 
@@ -20,7 +20,7 @@ uname | grep MINGW && options="$common --enable-memalign-hack --enable-mingw32 -
 
 #Get ffmpeg from svn
 svn -r $FFMPEG_REVISION co $FFMPEG_SVN $FFMPEG_CO_DIR
-sh -c "$FFMPEG_EXTERNALS_UPDATE"
+svn update -r $FFMPEG_EXTERNALS_REVISION $FFMPEG_CO_DIR/libswscale
 
 #configure and build ffmpeg
 cd ffmpeg && ./configure $options && make
