@@ -103,6 +103,8 @@ oggmux_info info;
 
 static int using_stdin = 0;
 
+static int padcolor[3] = { 16, 128, 128 };
+
 
 /**
  * Allocate and initialise an AVFrame.
@@ -362,17 +364,6 @@ void ff2theora_output(ff2theora this) {
             this->picture_width = this->picture_width - this->picture_width%2;
         }
 
-        if(this->no_upscaling) {
-            if(this->picture_width && this->picture_width > venc->width) {
-                this->picture_width = venc->width;
-                this->picture_height = venc->height;
-            }
-            if(this->fps < (double)this->framerate_new.num / this->framerate_new.den) {
-                this->framerate_new.num = vstream->r_frame_rate.num;
-                this->framerate_new.den = vstream->r_frame_rate.den;
-            }
-        }
-
         if(this->preset == V2V_PRESET_PREVIEW){
             if(abs(this->fps-30)<1 && (venc->width!=NTSC_HALF_WIDTH || venc->height!=NTSC_HALF_HEIGHT) ){
                 this->picture_width=NTSC_HALF_WIDTH;
@@ -490,6 +481,18 @@ void ff2theora_output(ff2theora this) {
             this->picture_width = this->picture_width + this->picture_width%2;
           }
         }
+
+        if(this->no_upscaling) {
+            if(this->picture_width && this->picture_width > venc->width) {
+                this->picture_width = venc->width;
+                this->picture_height = venc->height;
+            }
+            if(this->fps < (double)this->framerate_new.num / this->framerate_new.den) {
+                this->framerate_new.num = vstream->r_frame_rate.num;
+                this->framerate_new.den = vstream->r_frame_rate.den;
+            }
+        }
+
         if(this->picture_height==0 &&
             (this->frame_leftBand || this->frame_rightBand || this->frame_topBand || this->frame_bottomBand) ){
             this->picture_height=venc->height-
@@ -575,7 +578,7 @@ void ff2theora_output(ff2theora this) {
                           venc->width - (this->frame_leftBand + this->frame_rightBand),
                           venc->height - (this->frame_topBand + this->frame_bottomBand),
                           this->pix_fmt,
-                          this->frame_width, this->frame_height, this->pix_fmt,
+                          this->picture_width, this->picture_height, this->pix_fmt,
                           sws_flags, NULL, NULL, NULL
             );
             fprintf(stderr, "  Resize: %dx%d",venc->width,venc->height);
@@ -650,6 +653,9 @@ void ff2theora_output(ff2theora this) {
         AVFrame *output_buffered=NULL;
         AVFrame *output_cropped_p=NULL;
         AVFrame *output_cropped=NULL;
+        AVFrame *output_padded_p=NULL;
+        AVFrame *output_padded=NULL;
+                        
         
 
         AVPacket pkt;
@@ -687,12 +693,14 @@ void ff2theora_output(ff2theora this) {
             output_p = output = frame_alloc(this->pix_fmt,
                             vstream->codec->width,vstream->codec->height);
             output_resized_p = output_resized = frame_alloc(this->pix_fmt,
-                            this->frame_width, this->frame_height);
+                            this->picture_width, this->picture_height);
             output_cropped_p = output_cropped = frame_alloc(this->pix_fmt,
                             vstream->codec->width-this->frame_leftBand,
                             vstream->codec->height-this->frame_topBand);
             output_buffered_p = output_buffered = frame_alloc(this->pix_fmt,
                             this->frame_width, this->frame_height);
+            output_padded_p = output_padded = frame_alloc(this->pix_fmt,
+                            this->frame_width, this->frame_height);
 
             /* video settings here */
             /* config file? commandline options? v2v presets? */
@@ -757,7 +765,7 @@ void ff2theora_output(ff2theora this) {
                   fprintf(stderr, "WARNING - Subtitles language not set for input file %d\n",i);
                 }
                 kate_info_set_language(ki, ks->subtitles_language);
-                kate_info_set_category(ki, ks->subtitles_category[0]?ks->subtitles_category:"subtitles");
+                kate_info_set_category(ki, ks->subtitles_category[0]?ks->subtitles_category:"SUB");
                 if(this->force_input_fps.num > 0) {
                     ki->gps_numerator = this->force_input_fps.num;    /* fps= numerator/denominator */
                     ki->gps_denominator = this->force_input_fps.den;
@@ -933,7 +941,18 @@ void ff2theora_output(ff2theora this) {
                             else{
                                 output_resized = output_cropped;
                             }
-
+                            if ((this->frame_width!=this->picture_width) || (this->frame_height!=this->picture_height)) {
+                              if (av_picture_pad((AVPicture *)output_padded,
+                                                 (AVPicture *)output_resized,
+                                                 this->frame_height, this->frame_width, this->pix_fmt,
+                                                 0, this->frame_height - this->picture_height,
+                                                 0, this->frame_width - this->picture_width,
+                                                 padcolor ) < 0 ) {
+                                av_log(NULL, AV_LOG_ERROR, "error padding frame\n");
+                              }
+                            } else {
+                              output_padded = output_resized;
+                            }
                         }
                         ptr += len1;
                         len -= len1;
@@ -951,7 +970,7 @@ void ff2theora_output(ff2theora this) {
                     }
                     if(got_picture) {
                       first=0;
-                      av_picture_copy ((AVPicture *)output_buffered, (AVPicture *)output_resized, this->pix_fmt, this->frame_width, this->frame_height);
+                      av_picture_copy ((AVPicture *)output_buffered, (AVPicture *)output_padded, this->pix_fmt, this->frame_width, this->frame_height);
                     }
                     if(!got_picture){
                         break;
@@ -1051,6 +1070,7 @@ void ff2theora_output(ff2theora this) {
             frame_dealloc(output_resized_p);
             frame_dealloc(output_buffered_p);
             frame_dealloc(output_cropped_p);
+            frame_dealloc(output_padded_p);
         }
         av_free(audio_buf);
         av_free(resampled);
@@ -1200,7 +1220,7 @@ void print_usage (){
         "      --no-skeleton      disables ogg skeleton metadata output\n"
         "  -s, --starttime        start encoding at this time (in sec.)\n"
         "  -e, --endtime          end encoding at this time (in sec.)\n"
-        "  -p, --v2v-preset       encode file with v2v preset.\n"
+        "  -p, --preset           encode file with preset.\n"
         "                          Right now there is preview, pro and videobin. Run\n"
         "                          '"PACKAGE" -p info' for more informations\n"
         "\n"
@@ -1360,7 +1380,7 @@ int main (int argc, char **argv){
 #endif
       {"framerate",required_argument,NULL,'F'},
       {"aspect",required_argument,&flag,ASPECT_FLAG},
-      {"v2v-preset",required_argument,NULL,'p'},
+      {"preset",required_argument,NULL,'p'},
       {"nice",required_argument,NULL,'N'},
       {"croptop",required_argument,&flag,CROPTOP_FLAG},
       {"cropbottom",required_argument,&flag,CROPBOTTOM_FLAG},
@@ -1464,7 +1484,6 @@ int main (int argc, char **argv){
                             flag = -1;
                             break;
                         case FRONTENDFILE_FLAG:
-                            fprintf(stderr, "set output: %s!!!\n", optarg);
                             info.frontend = fopen(optarg, "w");
                             flag = -1;
                             break;
@@ -1802,7 +1821,7 @@ int main (int argc, char **argv){
           printf("Muxing Kate stream %d from %s as %s %s\n",
               n,ks->filename,
               ks->subtitles_language[0]?ks->subtitles_language:"<unknown language>",
-              ks->subtitles_category[0]?ks->subtitles_category:"subtitles");
+              ks->subtitles_category[0]?ks->subtitles_category:"SUB");
         }
         else {
           if (n!=convert->n_kate_streams) {
